@@ -9,11 +9,10 @@ import cgi
 import datetime
 import os
 import pkg_resources
-import py
 import time
-import sys
 import shutil
 
+import py
 from py.xml import html
 from py.xml import raw
 
@@ -66,7 +65,7 @@ class HTMLReport(object):
                 links.update({'HTML': os.path.join(relative_path, filename)})
 
             # Log may contain passwords, etc so we only capture it for tests marked as public
-            if report.debug['logs'] and 'public' in report.keywords:
+            if report.public and report.debug['logs']:
                 filename = 'log.txt'
                 f = open(os.path.join(full_path, filename), 'wb')
                 f.write(report.debug['logs'][-1])
@@ -108,6 +107,7 @@ class HTMLReport(object):
             if report.longrepr:
                 log = html.div(class_='log')
                 for line in str(report.longrepr).splitlines():
+                    line = line.decode('utf-8')
                     separator = line.startswith('_ ' * 10)
                     if separator:
                         log.append(line[:80])
